@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 BEGIN {
-  $CPAN::Perl::Releases::VERSION = '0.14';
+  $CPAN::Perl::Releases::VERSION = '0.16';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -122,6 +122,10 @@ our $data =
     "tar.bz2" => "L/LB/LBROCARD/perl-5.12.4-RC1.tar.bz2",
     "tar.gz" => "L/LB/LBROCARD/perl-5.12.4-RC1.tar.gz",
   },
+  "5.12.4-RC2" => {
+    "tar.bz2" => "L/LB/LBROCARD/perl-5.12.4-RC2.tar.bz2",
+    "tar.gz" => "L/LB/LBROCARD/perl-5.12.4-RC2.tar.gz",
+  },
   "5.13.0" => {
     "tar.bz2" => "L/LB/LBROCARD/perl-5.13.0.tar.bz2",
     "tar.gz" => "L/LB/LBROCARD/perl-5.13.0.tar.gz",
@@ -298,7 +302,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.14
+version 0.16
 
 =head1 SYNOPSIS
 
